@@ -16,6 +16,16 @@ secsTable = [
 	( 1, "s", "second" )
 	]
 
+
+#########################
+def limitSecsToStr(secs):
+	'''Remove conversion settings that are greater than "secs" long.
+	Can only be called once per program run.'''
+	while secsTable[0][0] > secs:
+		del(secsTable[0])
+
+
+###############################
 def secsToStr(secs, max = 100):
 	str = ""
 
@@ -30,6 +40,8 @@ def secsToStr(secs, max = 100):
 			break
 	return(str)
 
+
+######################
 def bytesToStr(bytes):
 	try:
 		if (bytes > 1024000000):
